@@ -2,6 +2,7 @@ import socket
 import pickle
 import json
 from omnitools import args
+from .utils import *
 
 
 __ALL__ = ["SC"]
@@ -29,5 +30,8 @@ class SC(object):
             recv += self.s.recv(len_response-len(recv))
             if not recv:
                 break
-        return json.loads(recv.decode())
+        try:
+            return json.loads(recv.decode())
+        except UnicodeDecodeError:
+            return pickle.loads(recv)
 
